@@ -1,3 +1,6 @@
+#  Copyright 2021 Amazon.com, Inc. or its affiliates. All Rights Reserved.
+#  SPDX-License-Identifier: Apache-2.0
+
 import json
 import logging
 import os
@@ -9,7 +12,6 @@ from datetime import datetime
 import click
 from betterboto import client as betterboto_client
 
-
 from servicecatalog_puppet import (
     aws,
     config,
@@ -24,13 +26,14 @@ from servicecatalog_puppet.workflow.lambda_invocations import (
     lambda_invocation_section_task,
 )
 from servicecatalog_puppet.workflow.launch import launch_section_task
-from servicecatalog_puppet.workflow.stack import stack_section_task
-from servicecatalog_puppet.workflow.spoke_local_portfolios import (
-    spoke_local_portfolio_section_task,
-)
 from servicecatalog_puppet.workflow.launch.reset_provisioned_product_owner_task import (
     ResetProvisionedProductOwnerTask,
 )
+from servicecatalog_puppet.workflow.spoke_local_portfolios import (
+    spoke_local_portfolio_section_task,
+)
+from servicecatalog_puppet.workflow.stack import stack_section_task
+from servicecatalog_puppet.workflow.workspaces import workspace_section_task
 
 logger = logging.getLogger()
 logger.setLevel(logging.INFO)
@@ -270,6 +273,12 @@ def generate_tasks(
         stack_section_task.StackSectionTask(
             manifest_file_path=f.name, puppet_account_id=puppet_account_id,
         ),
+        # app_section_task.AppSectionTask(
+        #     manifest_file_path=f.name, puppet_account_id=puppet_account_id,
+        # ),
+        workspace_section_task.WorkspaceSectionTask(
+            manifest_file_path=f.name, puppet_account_id=puppet_account_id,
+        ),
     ]
     if execution_mode != constants.EXECUTION_MODE_SPOKE:
         if not is_dry_run:
