@@ -87,7 +87,9 @@ PARTITION_ENVIRONMENTAL_VARIABLE_NAME = "PARTITION"
 PARTITION_SSM_PARAMETER_VARIABLE_NAME = "/servicecatalog-puppet/partition"
 
 PUPPET_ROLE_NAME_DEFAULT = "PuppetRole"
+PUPPET_STACK_ROLE_NAME_DEFAULT = "PuppetStackRole"
 PUPPET_ROLE_NAME_ENVIRONMENTAL_VARIABLE_NAME = "PUPPET_ROLE_NAME"
+PUPPET_STACK_ROLE_NAME_ENVIRONMENTAL_VARIABLE_NAME = "PUPPET_STACK_ROLE_NAME"
 PUPPET_ROLE_NAME_SSM_PARAMETER_VARIABLE_NAME = "/servicecatalog-puppet/puppet-role/name"
 
 PUPPET_ROLE_PATH_DEFAULT = "/servicecatalog-puppet/"
@@ -102,6 +104,9 @@ START_SHARED_SCHEDULER_COMMAND = "luigid --background --pidfile luigi.pid --logd
 
 CONFIG_REGIONS = "regions"
 CONFIG_SHOULD_COLLECT_CLOUDFORMATION_EVENTS = "should_collect_cloudformation_events"
+CONFIG_SHOULD_USE_STACKS_SERVICE_ROLE = "should_use_stacks_service_role"
+MANIFEST_SHOULD_USE_STACKS_SERVICE_ROLE = "use_stacks_service_role"
+CONFIG_SHOULD_USE_STACKS_SERVICE_ROLE_DEFAULT = False
 CONFIG_SHOULD_USE_SHARED_SCHEDULER = "should_use_shared_scheduler"
 CONFIG_SHOULD_EXPLODE_MANIFEST = "should_explode_manifest"
 
@@ -171,3 +176,7 @@ TERMINATE_DRY_RUN_TERRAFORM_PROJECT_NAME = (
     "servicecatalog-puppet-terminate-dry-run-terraform"
 )
 TERRAFORM_SPOKE_PREP_STACK_NAME = f"{BOOTSTRAP_STACK_NAME}-terraform-execution"
+STACK_SPOKE_PREP_STACK_NAME = f"{BOOTSTRAP_STACK_NAME}-stack-execution"
+
+
+USE_SERVICE_ROLE_DEFAULT = False
